@@ -38,8 +38,10 @@ if __name__ == '__main__':
     parser.add_argument('-g','--gpu', type=int, default=0)
     parser.add_argument('--max_iteration', type=int, default=30000)
     parser.add_argument('--seed', type=int, default=124)
-    parser.add_argument('--chunk_size', type=int, default=100000)
+    parser.add_argument('--chunk_size', type=int, default=20000)
     parser.add_argument('--ignore_umap', action='store_true')
+    parser.add_argument('--repeat', action='store_true')
+    parser.add_argument('--partial', action='store_true')
 #     parser.add_argument('--beta', type=float, default=0.5)
 #     parser.add_argument('--hid_dim', type=int, default=1024)
 #     parser.add_argument('--eval', action='store_true')
@@ -66,5 +68,7 @@ if __name__ == '__main__':
         projection=args.projection, 
         chunk_size=args.chunk_size,
         ignore_umap=args.ignore_umap,
+        repeat=args.repeat,
+        partial=args.partial,
         verbose=True
     )
