@@ -147,22 +147,24 @@ def preprocessing(
         cell_subsets.append(cell_subset)
     indices = np.where(np.concatenate(cell_subsets))[0]
     adata = adata[indices]
-
-#     sc.pp.filter_cells(adata, min_genes=min_genes)
     
     if log: log.info('Filtering genes')
-#     adata = adata[np.where(np.sum(adata.X>0, 0))]
     sc.pp.filter_genes(adata, min_cells=min_cells)
-    from sklearn.utils import sparsefuncs
-    if log: log.info('Normalizing total to {}'.format(target_sum))
-#     for i in range(adata.shape[0]//chunk_size+1):
-#         log.info(i)
-#         counts = np.ravel(adata.X[i*chunk_size:(i+1)*chunk_size].sum(1))
-#         log.info('counts')
-#         sparsefuncs.inplace_row_scale(adata.X[i*chunk_size:(i+1)*chunk_size], target_sum/counts)
-#         adata.X[i*chunk_size:(i+1)*chunk_size] = sc.pp.normalize_total(adata[i*chunk_size:(i+1)*chunk_size], target_sum=target_sum, exclude_highly_expressed=True, inplace=False)['X']
-    sc.pp.normalize_total(adata, target_sum=target_sum, exclude_highly_expressed=True)
+#     adata = adata[np.where(np.sum(adata.X>0, 0))]
+#     gene_set, _ = sc.pp.filter_genes(adata, min_cells=min_cells, inplace=False)
+#     log.info('subset gene')
+#     adata = adata[:, np.where(gene_set)[0]]
 
+    if log: log.info('Normalizing total to {}'.format(target_sum))
+    X_ = []
+    for i in range(adata.shape[0]//chunk_size+1):
+        X = sc.pp.normalize_total(adata[i*chunk_size:(i+1)*chunk_size], target_sum=target_sum, exclude_highly_expressed=True, inplace=False)['X']
+        X_.append(X)
+#     sc.pp.normalize_total(adata, target_sum=target_sum, exclude_highly_expressed=True)
+    adata.X = scipy.sparse.vstack(X_)
+    del X_
+    del X
+    
     if log: log.info('Log1p transforming')
     sc.pp.log1p(adata) #, chunked=True, chunk_size=chunk_size)
     
