@@ -46,7 +46,7 @@ def SCALEX(
         verbose=False,
     ):
     
-    sc.logging.print_versions()
+#     sc.logging.print_versions()
     np.random.seed(seed) # seed
     torch.manual_seed(seed)
 
@@ -113,8 +113,8 @@ def SCALEX(
     adata.obsm['latent'] = model.encodeBatch(testloader, device=device) # save latent rep
     if impute:
         adata.layers['impute'] = model.encodeBatch(testloader, out='impute', device=device)
+    log.info('Output dir: {}'.format(outdir))
         
-    log.info(outdir)
     if projection and (not repeat):
         ref = sc.read_h5ad(projection+'/adata.h5ad')
         adata = AnnData.concatenate(
@@ -123,8 +123,9 @@ def SCALEX(
             batch_key='projection', 
             index_unique=None
         )
-        
-    if not ignore_umap:
+    adata.write(outdir+'adata.h5ad', compression='gzip')  
+    if not ignore_umap: #and adata.shape[0]<1e6:
+        log.info('Plot umap')
         sc.pp.neighbors(adata, n_neighbors=30, use_rep='latent')
         sc.tl.umap(adata, min_dist=0.1)
         sc.tl.leiden(adata)
@@ -139,16 +140,17 @@ def SCALEX(
                 plot_umap(adata, cond1='projection', save='.pdf')
             else:
                 sc.pl.umap(adata, color=color, save='.pdf', wspace=0.4, ncols=4)
+                
+#         if len(adata.obs['batch'].cat.categories) > 1:
+#             entropy_score = entropy_batch_mixing(adata.obsm['X_umap'], adata.obs['batch'])
+#             log.info('entropy_batch_mixing: {:.3f}'.format(entropy_score))
+
+#         if 'celltype' in adata.obs:
+#             sil_score = silhouette_score(adata.obsm['X_umap'], adata.obs['celltype'].cat.codes)
+#             log.info("silhouette_score: {:.3f}".format(sil_score))
 
     adata.write(outdir+'adata.h5ad', compression='gzip')
         
         
-                
-#                 if len(adata.obs['batch'].cat.categories) > 1:
-#                     entropy_score = entropy_batch_mixing(adata.obsm['X_umap'], adata.obs['batch'])
-#                     log.info('entropy_batch_mixing: {:.3f}'.format(entropy_score))
 
-#                 if 'celltype' in adata.obs:
-#                     sil_score = silhouette_score(adata.obsm['X_umap'], adata.obs['celltype'].cat.codes)
-#                     log.info("silhouette_score: {:.3f}".format(sil_score))
 
